package dragonwell.dump;

import io.vertx.core.AbstractVerticle;
import io.vertx.core.Context;
import io.vertx.core.Promise;
import io.vertx.core.Vertx;
import io.vertx.reactivex.ext.web.Router;
import io.vertx.pgclient.PgConnectOptions;
import io.vertx.reactivex.pgclient.PgPool;
import io.vertx.reactivex.sqlclient.SqlClient;
import io.vertx.reactivex.sqlclient.Tuple;
import io.vertx.sqlclient.PoolOptions;

public class MainVerticle extends AbstractVerticle {
  protected io.vertx.reactivex.core.Vertx vertx;
  private SqlClient sqlClient;

  @Override
  public void init(Vertx vertx, Context context) {
    super.init(vertx, context);
    this.vertx = new io.vertx.reactivex.core.Vertx(vertx);
    this.sqlClient = createSqlClient();
  }

  @Override
  public void start(Promise<Void> startPromise) throws Exception {
    vertx
      .createHttpServer()
      .requestHandler(createRouter())
      .listen(
        8888,
        http -> {
          if (http.succeeded()) {
            startPromise.complete();
            System.out.println("HTTP server started on port 8888");
          } else {
            startPromise.fail(http.cause());
          }
        });
  }

  private Router createRouter() {
    Router router = Router.router(vertx);
    router
      .route("/dump")
      .blockingHandler(
        req -> {
          String version =
            sqlClient
              .preparedQuery("SHOW server_version")
              .rxExecute()
              .map(rows -> rows.iterator().next().getString("server_version"))
              .blockingGet();
          req.response().putHeader("content-type", "text/plain").end(version);
        });
    return router;
  }

  private SqlClient createSqlClient() {
    PgConnectOptions connectOptions =
      new PgConnectOptions()
        .setPort(6432)
        .setHost("localhost")
        .setDatabase("dump")
        .setUser("postgres")
        .setPassword("postgres");
    PoolOptions poolOptions = new PoolOptions();
    return PgPool.pool(vertx, connectOptions, poolOptions);
  }
}
